<?php
// $Id: chessboard_render.php,v 1.16 2010/07/25 23:53:20 erica Exp $

/**
 * @file
 * Theme related functions for the Chessboard Renderer module.
 */

$chessboard_image_path = '/images/';


/*================================*/
/* Configuration                  */
/*================================*/

function chessboard_image_path($path) {
  global $chessboard_image_path;
  $chessboard_image_path = $path;
}


/*================================*/
/* Routines                       */
/*================================*/

function chessboard_border_filename($border) {
  // $border: T, B, L, R, TL, TR, BL, BR
  global $chessboard_image_path;

  switch ($border) {
    case 'T':
    case 'B':
      return $chessboard_image_path . 'h.png';
    case 'L':
    case 'R':
      return $chessboard_image_path . 'v.png';
    default:
      return $chessboard_image_path . 'c.png';
  }
}


function chessboard_piece_filename($piece, $square_color) {
  // $piece        : KQBNRPkqbnrp-
  // $square_color : 0 1
  global $chessboard_image_path;

  switch ($piece) {
    case 'x':
      $name = 'xx';
      break;
    case '-':
      $name = '';
      break;
    default:
      $name = strtolower($piece) . (ctype_lower($piece) ? 'd' : 'l');
      break;
  }

  return $chessboard_image_path . $name . ($square_color ? 'd' : 'l') . '.png';
}

function chessboard_render($content) {
  $item = array(
    'value' => $content,
  );
  $node = NULL;
  $field = array();
  $items = array($item);
  chessboard_field('sanitize', $node, $field, $items, FALSE, FALSE);
  $element = chessboard_formatter_view($items);
  foreach (element_children($element) as $delta) {
    unset($element[$delta]['#prefix'], $element[$delta]['#suffix']);
  }
  $output = drupal_render($element);
  chessboard_process_attached($element);
  return $output;
}

/**
 * Formats Chessboard Renderer notation syntax in HTML.
 *
 * @param $element
 *    An associative array containing items (chessboards) as children keyed by delta.
 *
 * @ingroup themable
 */
function theme_chessboard_formatter_chessboard_default($element) {
  $items = array();
  foreach (element_children($element) as $key) {
    $items[$key] = $element[$key]['#item'];
  }
  $element = chessboard_formatter_view($items);
  $output = drupal_render($element);
  chessboard_process_attached($element);
  return $output;
}

function template_preprocess_chessboard(&$variables) {
  chessboard_image_path(base_path() . drupal_get_path('module', 'chessboard') . '/default/');
  static $table_constructed = FALSE;
  static $table_xhtml;

  if (!$table_constructed) {

    // Construct the translation table

    // Empty and marked squares
    $table_xhtml = array('-0' => '<img class="chessboard-square" src="'
                           . chessboard_piece_filename('-', 0)
                           . '" alt="-" />',
                         '-1' => '<img class="chessboard-square" src="'
                           . chessboard_piece_filename('-', 1)
                           . '" alt="-" />',
                         'x0' => '<img class="chessboard-square" src="'
                           . chessboard_piece_filename('x', 0)
                           . '" alt="x" />',
                         'x1' => '<img class="chessboard-square" src="'
                           . chessboard_piece_filename('x', 1)
                           . '" alt="x" />',
                        );

    // Pieces
    $pieces = 'kqbnrp';
    for ($i=0; $i<6; $i++) {
      $piece = $pieces[$i];
      $table_xhtml += array(strtoupper($piece) . '0' => '<img class="chessboard-square" src="'
                              . chessboard_piece_filename(strtoupper($piece), 0)
                              . '" alt="' . strtoupper($piece) . '" />',
                            strtoupper($piece) . '1' => '<img class="chessboard-square" src="'
                              . chessboard_piece_filename(strtoupper($piece), 1)
                              . '" alt="' . strtoupper($piece) . '" />',
                            $piece . '0' => '<img class="chessboard-square" src="'
                              . chessboard_piece_filename($piece, 0)
                              . '" alt="' . $piece . '" />',
                            $piece . '1' => '<img class="chessboard-square" src="'
                              . chessboard_piece_filename($piece, 1)
                              . '" alt="' . $piece . '" />',
      );
    }

    // Borders
    $table_xhtml += array('T' => '<img class="chessboard-border-h" src="'
                            . chessboard_border_filename('T')
                            . '" alt="" />',
                          'B' => '<img class="chessboard-border-h" src="'
                            . chessboard_border_filename('B')
                            . '" alt="" />',
                          'L' => '<img class="chessboard-border-v" src="'
                            . chessboard_border_filename('L')
                            . '" alt="" />',
                          'R' => '<img class="chessboard-border-v" src="'
                            . chessboard_border_filename('R')
                            . '" alt="" />',
                          'TL' => '<img class="chessboard-border-c" src="'
                            . chessboard_border_filename('TL')
                            . '" alt="" />',
                          'TR' => '<img class="chessboard-border-c" src="'
                            . chessboard_border_filename('TR')
                            . '" alt="" />',
                          'BL' =>
                            '<img class="chessboard-border-c" src="'
                            . chessboard_border_filename('BL')
                            . '" alt="" />',
                          'BR' =>
                            '<img class="chessboard-border-c" src="'
                            . chessboard_border_filename('BR')
                            . '" alt="" />',
    );

    $table_constructed = TRUE;
  }
  $variables['table_xhtml'] = $table_xhtml;
  // For convenience.
  $variables['file_max'] = $variables['element']['#item']['file_max'];
  $variables['square_color_first'] = $variables['element']['#item']['square_color_first'];
  $variables['border'] = $variables['element']['#item']['border'];
  $variables['board'] = $variables['element']['#item']['board'];
}
